@@ -45,6 +45,25 @@ sub is_installed($) {
     }    
 }
 
+sub is_available($) {
+    my ($pack) = @_;
+    my $p = $cache->{$pack};
+    my $res = 0;
+    log_msg("$0: Package: $pack");
+
+    if (my $available = $p->{VersionList})
+    {
+        # Check the first available version in package version list
+        # we only care about the latest package anyway.
+        $curver = @$available[0]->{VerStr};
+    	log_msg("$0: Package $p is available");
+	$res = 1;
+    }
+    
+    return $res;
+}
+
+
 # We only use this subroutine from the scripts.
 # It takes the package name and it's version map
 # and it returns the most probable release name for
@@ -111,7 +130,7 @@ sub check_vermap($) {
 sub get_debian_version {
     my %supported_versions = (  'woody'            => { RELEASE => 'woody' },
                                 'sarge'            => { RELEASE => 'sarge' },
-                                'testing/unstable' => { RELEASE => 'sarge' },
+                                'testing/unstable' => { RELEASE => 'etch' },
 				'3.1'              => { RELEASE => 'sarge' }
                              );
     my $debver_file= "/etc/debian_version";
