@@ -12,7 +12,8 @@ my %lang_X_map = (
     'American (US)'      => { XkbLayout => 'us', XkbModel => 'pc104'},
     'Australian'         => { XkbLayout => 'us', XkbModel => 'pc104' },
     'Belarussian'        => { XkbLayout => 'us,ru', XkbOptions => 'grp:ctrl_shift_toggle,grp_led:scroll', XkbModel => 'pc105', XkbVariant => 'winkeys' },
-    'Belgian'            => { XkbLayout => 'be', XkbModel => 'pc105' },
+    'French (BE)'        => { XkbLayout => 'be', XkbModel => 'pc105' },
+    'Dutch (BE)'         => { XkbLayout => 'be', XkbModel => 'pc105' },
     'Bosnian'            => { XkbLayout => 'us,bs', XkbOptions => 'grp:alt_shift_toggle', XkbModel => 'pc105' },
     'Brazilian'          => { XkbLayout => 'br', XkbModel => 'abnt2', XkbVariant => 'abnt2' },
     'Brazilian (latin1)' => { XkbLayout => 'us_intl', XkbModel => 'pc105' },
